import React, { useState } from 'react';
import { Space, Table, Button, Input, Select, DatePicker } from 'antd';
import type { TableProps } from 'antd';
import styles from './index.module.css';
import AddPunlishPlanModal from './components/publishPlanModal';
const { RangePicker } = DatePicker;

interface DataType {
	// key: string;
	officialAccount: string;
	scene: string;
	videoCount: number;
	videoTitle: string;
	planPublishTime: string;
	publisher: string;
}

const WeGZHContent: React.FC = () => {
	// 状态管理
	const [selectedAccount, setSelectedAccount] = useState<string>();
	const [videoTitle, setVideoTitle] = useState<string>('');
	const [selectedPublisher, setSelectedPublisher] = useState<string>();
	const [dateRange, setDateRange] = useState<[string, string]>();
	const [isShowAddPunlishPlan, setIsShowAddPunlishPlan] = useState<boolean>(false);

	// 表格列配置
	const columns: TableProps<DataType>['columns'] = [
		{
			title: '公众号名称',
			dataIndex: 'officialAccount',
			key: 'officialAccount',
		},
		{
			title: '场景',
			dataIndex: 'scene',
			key: 'scene',
		},
		{
			title: '视频数量',
			dataIndex: 'videoCount',
			key: 'videoCount',
		},
		{
			title: '视频标题',
			dataIndex: 'videoTitle',
			key: 'videoTitle',
			ellipsis: true,
		},
		{
			title: '计划创建时间',
			dataIndex: 'planPublishTime',
			key: 'planPublishTime',
		},
		{
			title: '发布方',
			dataIndex: 'publisher',
			key: 'publisher',
		},
		{
			title: '操作',
			key: 'action',
			render: (_, record) => (
				<Space size="middle">
					<Button type="link">编辑</Button>
					<Button type="link">详情</Button>
				</Space>
			),
		},
	];

	// 模拟数据
	const data: DataType[] = [
		{
			officialAccount: '小慧爱厨房',
			scene: '关注回复',
			videoCount: 3,
			videoTitle: '养老金最新规定，快来看看...',
			planPublishTime: '2024-08-13 13:32:07',
			publisher: '平台发布',
		},
		{
			officialAccount: '小阳看天下',
			scene: '关注回复',
			videoCount: 1,
			videoTitle: '养老金最新规定，快来看看...',
			planPublishTime: '2024-08-13 13:32:07',
			publisher: '用户发布',
		},
	];

	const addPunlishPlan = () => {
		setIsShowAddPunlishPlan(true);
	}

	return (
		<div>
			<div className="bg-white rounded-lg">
				<div className="text-lg font-medium mb-3">公众号内容</div>
				
				{/* 搜索区域 */}
				<div className="flex flex-wrap gap-4 mb-3">
					<div className="flex items-center gap-2">
						<span className="text-gray-600">公众号名称:</span>
						<Select
							placeholder="选择公众号"
							style={{ width: 200 }}
							value={selectedAccount}
							onChange={setSelectedAccount}
							options={[
								{ label: '小慧爱厨房', value: '小慧爱厨房' },
								{ label: '小阳看天下', value: '小阳看天下' },
							]}
						/>
					</div>

					<div className="flex items-center gap-2">
						<span className="text-gray-600">视频标题:</span>
						<Input
							placeholder="搜索视频标题"
							style={{ width: 200 }}
							value={videoTitle}
							onChange={e => setVideoTitle(e.target.value)}
						/>
					</div>

					<div className="flex items-center gap-2">
						<span className="text-gray-600">发布方:</span>
						<Select
							placeholder="选择发布方"
							style={{ width: 200 }}
							value={selectedPublisher}
							onChange={setSelectedPublisher}
							options={[
								{ label: '平台发布', value: 'platform' },
								{ label: '用户发布', value: 'user' },
							]}
						/>
					</div>

					<div className="flex items-center gap-2">
						<RangePicker
							placeholder={['开始时间', '结束时间']}
							style={{ width: 400 }}
							onChange={(dates, dateStrings) => {
								if (dates) {
									setDateRange([dateStrings[0], dateStrings[1]]);
								} else {
									setDateRange(undefined);
								}
							}}
						/>
					</div>

					<Button type="primary" className="ml-2">搜索</Button>
				</div>
				{/* 表格区域 */}
				<Table
					title={() =>
						<div className="flex justify-between">
							<div className="text-[#333] font-medium px-[45px] py-[15px] rounded-tr-[20px] bg-[#ffc107] text-[16px] border-none hover:bg-[#ffca2c]">
								自动回复
							</div>
							<Button type="primary" onClick={addPunlishPlan}>+ 创建发布</Button>
						</div>
					}
					rowKey={(record) => record.officialAccount}
					className={styles.antTable}
					columns={columns}
					dataSource={data}
					pagination={{
						total: data.length,
						pageSize: 10,
						showTotal: (total) => `共 ${total} 条`,
					}}
				/>
				<AddPunlishPlanModal
					visible={isShowAddPunlishPlan}
					onCancel={() => setIsShowAddPunlishPlan(false)}
					onOk={() => setIsShowAddPunlishPlan(false)}
				/>
			</div>
		</div>
	);
};

export default WeGZHContent;
